<!-- ⚠️ This is an open-source repository. Do not share sensitive information. -->

<!--
Thank you for the pull request.
Below are a few things we ask you kindly to self-check before getting a review. Remove checks that are not relevant.
-->

# Checklist

- [ ] Added a `CHANGELOG.rst` entry
